@@ -2,7 +2,7 @@
 
 package OCS::Client;
 # ABSTRACT: simple interface to OCS's SOAP API
-$OCS::Client::VERSION = '0.012';
+$OCS::Client::VERSION = '0.013';
 use utf8;
 use strict;
 use warnings;
@@ -13,6 +13,9 @@ use XML::Entities;
 use XML::Simple;
 
 
+our %ACCOUNT_INFO;
+
+
 sub new {
     my ($class, $url, $user, $pass, @args) = @_;
 
@@ -80,36 +83,6 @@ sub computer_iterator {
     };
 }
 
-# This hash is used to map OCS custom field ids (in the form
-# "fields_N") into their names.
-my %fields = (
-    3 => 'UA',
-    4 => 'Sala',
-    5 => 'Nome do Usuário',
-    6 => 'Atividade',
-    7 => 'Nome da Empresa',
-    8 => 'Ponto de Rede',
-    9 => 'Switch',
-    10 => 'Porta',
-    11 => 'Status',
-    13 => 'Observações',
-    14 => 'Local do Ponto',
-    15 => 'Asset Number',
-    16 => 'Responsável',
-    17 => 'Tipo',
-    18 => 'Padrão de HW',
-    19 => 'Data de Aquisição',
-    20 => 'UA Username',
-    21 => 'Office',
-    22 => 'Office Tag',
-    23 => 'PA',
-    25 => 'Nagios',
-    26 => 'Diretoria',
-    27 => 'Nota Fiscal',
-    28 => 'HW Guidelines',
-    29 => 'Físico/Virtual',
-);
-
 
 sub prune {
     my ($computer) = @_;
@@ -118,8 +91,8 @@ sub prune {
 	my %myinfo;
 	foreach my $info (grep {exists $_->{content}} @$accountinfo) {
 	    if ($info->{Name} =~ /^fields_(\d+)$/) {
-                if (exists $fields{$1}) {
-                    $myinfo{$fields{$1}} = $info->{content};
+                if (exists $ACCOUNT_INFO{$1}) {
+                    $myinfo{$ACCOUNT_INFO{$1}} = $info->{content};
                 } else {
                     carp "Skipping unknown ACCOUNTINFO field for $key: ($info->{Name} => $info->{content})";
                 }
@@ -215,7 +188,7 @@ OCS::Client - simple interface to OCS's SOAP API
 
 =head1 VERSION
 
-version 0.012
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -228,9 +201,16 @@ version 0.012
       checksum => OCS::Client::HARDWARE | OCS::Client::SOFTWARE,
   );
 
+  %OCS::Client::ACCOUNT_INFO = (
+    3  => 'UA',
+    4  => 'Room',
+    5  => 'Onwner',
+  );
+
   my $next_computer = $ocs->computer_iterator(asking_for => 'META');
   while (my $meta = $next_computer->()) {
       # ...
+      my $description = OCS::Client::prune($meta);
   }
 
 =head1 DESCRIPTION
@@ -243,6 +223,23 @@ SOAP API, which is somewhat specified in
 L<http://wiki.ocsinventory-ng.org/index.php/Developers:Web_services>.
 (This version is known to work against OCS 2.0.1.)
 
+=head2 VARIABLES
+
+=head3 B<%ACCOUNT_INFO>
+
+The B<get_computers_V1> method returns administrative information about each
+computer in the ACCOUNTINFO tag. This information is specific to the OCS
+instance. Unfortunately there's no way to grok this information
+programatically from the server, but you may register the mapping from the
+ACCOUNTINFO_ID to a descriptive name directly in this hash.
+
+You can see which administrative information is registered in the server by
+going to its web interface, clicking the 'Administrative Data' icon and the
+'download' link to download a CSV file containing the name ('Wording'
+column) and ID ('MODIF' column) of every information.
+
+This information is used by the B<prune> method below.
+
 =head2 METHODS
 
 =head3 B<new> OCSURL, USER, PASSWD [, <SOAP::Lite arguments>]
@@ -300,10 +297,7 @@ there were lots of frequently changing information that was
 uninportant to track.
 
 Note that it tries to convert the custom field names by using the
-OCS::Client::fields hash. This hash contains by default, the custom
-field names of my company's OCS instance. You should redefine it in
-your script if you intend to use this method. (May the source be with
-you, Luke!)
+B<%ACCOUNT_INFO> hash.
 
 =head2 CONSTANTS
 
